# IR

```{warning}
The Torii API reference is a work in progress and we are actively working on improving it,
however it may be deficient or missing in places.
```

```{eval-rst}
.. automodule:: torii.hdl.ir
  :members:

```
